@@ -19,8 +19,8 @@ class Meterpreter_mipsbe_Linux < Msf::Sessions::Meterpreter
   end
   def initialize(rstream, opts={})
     super
-    self.platform      = 'mipsbe/linux'
-    self.binary_suffix = 'lso'
+    self.base_platform = 'linux'
+    self.base_arch = ARCH_MIPSBE
   end
 end
 
