@@ -1,13 +1,11 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require "msf/core"
 require "rex/proto/pjl"
 
 class MetasploitModule < Msf::Auxiliary
-
   include Msf::Exploit::Remote::Tcp
   include Msf::Auxiliary::Scanner
   include Msf::Auxiliary::Report
@@ -34,7 +32,7 @@ class MetasploitModule < Msf::Auxiliary
 
     register_options([
       Opt::RPORT(Rex::Proto::PJL::DEFAULT_PORT),
-    ], self.class)
+    ])
   end
 
   def run_host(ip)
@@ -58,5 +56,4 @@ class MetasploitModule < Msf::Auxiliary
       )
     end
   end
-
 end
