@@ -1,9 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
 require 'msf/core/exploit/file_dropper'
 
 class MetasploitModule < Msf::Exploit::Remote
@@ -112,7 +111,7 @@ class MetasploitModule < Msf::Exploit::Remote
           [true, 'The target port', 8020]),
         OptString.new('WEB_ROOT',
           [false, 'Slash terminated web server root filepath (escape Windows paths with 4 slashes \\\\\\\\)'])
-      ], self.class)
+      ])
 
     register_advanced_options(
       [
@@ -122,7 +121,7 @@ class MetasploitModule < Msf::Exploit::Remote
           [true, 'Seconds to sleep between injections (x1 for MySQL, x2.5 for PostgreSQL)', 2]),
         OptBool.new('EXE_SMALL',
           [true, 'Use exe-small encoding for better reliability', true]),
-      ], self.class)
+      ])
 
   end
 
@@ -139,7 +138,7 @@ class MetasploitModule < Msf::Exploit::Remote
   def exploit
     @my_target = pick_target
     if @my_target.nil?
-      fail_with(Failure::NoTarget, "#{peer} - Automatic targeting failed.")
+      fail_with(Failure::NoTarget, "#{peer} - Automatic targeting failed")
     else
       print_status("Selected target #{@my_target.name}")
     end
