@@ -14,7 +14,7 @@ class MetasploitModule < Msf::Exploit::Remote
       'Name'           => 'Adobe IndesignServer 5.5 SOAP Server Arbitrary Script Execution',
       'Description'    => %q{
           This module abuses the "RunScript" procedure provided by the SOAP interface of
-        Adobe InDesign Server, to execute abritary vbscript (Windows) or applescript(OSX).
+        Adobe InDesign Server, to execute arbitrary vbscript (Windows) or applescript (OSX).
 
         The exploit drops the payload on the server and must be removed manually.
       },
