@@ -13,11 +13,11 @@ class MetasploitModule < Msf::Exploit::Remote
     super(update_info(info,
       'Name'           => "Honeywell Tema Remote Installer ActiveX Remote Code Execution",
       'Description'    => %q{
-          This modules exploits a vulnerability found in the Honewell Tema ActiveX Remote
+          This module exploits a vulnerability found in the Honeywell Tema ActiveX Remote
         Installer.  This ActiveX control can be abused by using the DownloadFromURL()
         function to install an arbitrary MSI from a remote location without checking source
         authenticity or user notification. This module has been tested successfully with
-        the Remote Installer ActiveX installed with HoneyWell EBI R410.1 - TEMA 5.3.0 and
+        the Remote Installer ActiveX installed with Honeywell EBI R410.1 - TEMA 5.3.0 and
         Internet Explorer 6, 7 and 8 on Windows XP SP3.
       },
       'License'        => MSF_LICENSE,
@@ -145,7 +145,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     if datastore['OBFUSCATE']
       js = ::Rex::Exploitation::JSObfu.new(js)
-      js.obfuscate
+      js.obfuscate(memory_sensitive: true)
     end
 
     html = <<-EOS
