@@ -266,7 +266,7 @@ else {
           }
         }
 
-        custom_js = ::Rex::Exploitation::ObfuscateJS.new(custom_js, opts).obfuscate()
+        custom_js = ::Rex::Exploitation::ObfuscateJS.new(custom_js, opts).obfuscate(memory_sensitive: true)
       end
 
     return <<-EOS
