@@ -176,7 +176,7 @@ function heapspray(){
   }
 }
     |
-    heapspray.obfuscate
+    heapspray.obfuscate(memory_sensitive: true)
 
     # Construct the final page
     case mytarget['Method']
