@@ -1,10 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-
-require 'msf/core'
 require 'rex/nop/opty2'
 
 
@@ -35,5 +33,4 @@ class MetasploitModule < Msf::Nop
 
     opty.generate_sled(length)
   end
-
 end
