@@ -1,11 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
-require 'rex'
-
 class MetasploitModule < Msf::Post
 
   def initialize(info={})
@@ -20,7 +17,7 @@ class MetasploitModule < Msf::Post
     register_options(
       [
         OptString.new( 'COMMAND', [false, 'The entire command line to execute on the session'])
-      ], self.class)
+      ])
   end
 
   def run
@@ -29,5 +26,4 @@ class MetasploitModule < Msf::Post
     print_status("Response: #{res}")
 
   end
-
 end
